@@ -1,11 +1,13 @@
 import binascii
 import glob
 import logging
+import shutil
 from os import path
 from pathlib import Path
+from typing import List, cast
 
 from erdpy import dependencies, errors, myprocess, utils
-import shutil
+from erdpy.dependencies.modules import StandaloneModule
 
 logger = logging.getLogger("Project")
 
@@ -22,15 +24,18 @@ class Project:
         self._copy_build_artifacts_to_output()
         self._create_deploy_files()
 
+    def clean(self):
+        utils.remove_folder(self._get_output_folder())
+
     def _ensure_dependencies_installed(self):
         module_keys = self.get_dependencies()
         for module_key in module_keys:
             dependencies.install_module(module_key)
 
-    def get_dependencies(self):
+    def get_dependencies(self) -> List[str]:
         raise NotImplementedError()
 
-    def perform_build(self):
+    def perform_build(self) -> None:
         raise NotImplementedError()
 
     def get_file_wasm(self):
@@ -55,13 +60,15 @@ class Project:
         file = path.join(folder, files[0])
         return Path(file).resolve()
 
-    def _copy_build_artifacts_to_output(self):
+    def _copy_build_artifacts_to_output(self) -> None:
         raise NotImplementedError()
 
     def _copy_to_output(self, file):
-        output_dir = path.join(self.directory, "output")
-        utils.ensure_folder(output_dir)
-        shutil.copy(file, output_dir)
+        utils.ensure_folder(self._get_output_folder())
+        shutil.copy(file, self._get_output_folder())
+
+    def _get_output_folder(self):
+        return path.join(self.directory, "output")
 
     def _create_deploy_files(self):
         file_wasm = self.get_file_wasm()
@@ -73,15 +80,14 @@ class Project:
             file.write(bytecode_hex)
 
     def get_bytecode(self):
-        bytecode = utils.read_file(self.get_file_wasm().with_suffix(".hex"))
-        return bytecode
+        bytecode = utils.read_file(self.get_file_wasm(), binary=True)
+        bytecode_hex = bytecode.hex()
+        return bytecode_hex
 
-    def run_tests(self, tests_directory, wildcard=None):
-        testrunner_module = dependencies.get_module_by_key("arwentools")
-        tool_directory = testrunner_module.get_directory()
-        tool_env = testrunner_module.get_env()
-
-        tool = path.join(tool_directory, "test")
+    def run_tests(self, tests_directory: str, wildcard: str = ""):
+        arwentools = cast(StandaloneModule, dependencies.get_module_by_key("arwentools"))
+        tool_env = arwentools.get_env()
+        tool = path.join(arwentools.get_parent_directory(), "mandos-test")
         test_folder = path.join(self.directory, tests_directory)
 
         if not wildcard:
