@@ -1,4 +1,5 @@
 import logging
+import os
 import subprocess
 from os import path
 
@@ -79,11 +80,14 @@ class ProjectCpp(Project):
         myprocess.run_process(args)
 
     def _copy_build_artifacts_to_output(self):
-        wasm_file = self.find_file_globally("*.cpp").with_suffix(".wasm")
-        self._copy_to_output(wasm_file)
+        source_file = self.find_file_globally("*.cpp")
+        self._copy_to_output(source_file.with_suffix(".wasm"))
+        os.remove(source_file.with_suffix(".wasm"))
+        os.remove(source_file.with_suffix(".ll"))
+        os.remove(source_file.with_suffix(".o"))
 
     def _get_llvm_path(self):
-        return dependencies.get_install_directory("llvm")
+        return dependencies.get_module_directory("llvm")
 
     def get_dependencies(self):
         return ["llvm"]
