@@ -14,6 +14,10 @@ class ProjectRust(Project):
         super().__init__(directory)
         self.cargo_file = self._get_cargo_file()
 
+    def clean(self):
+        super().clean()
+        utils.remove_folder(path.join(self.directory, "target"))
+
     def _get_cargo_file(self):
         cargo_path = path.join(self.directory, "Cargo.toml")
         return CargoFile(cargo_path)
@@ -41,7 +45,9 @@ class ProjectRust(Project):
 
             env["RUSTFLAGS"] = "-C link-arg=-s"
 
-        myprocess.run_process_async(args, env=env)
+        result = myprocess.run_process_async(args, env=env)
+        if result != 0:
+            raise errors.BuildError(f"error code = {result}, see output")
 
     def _copy_build_artifacts_to_output(self):
         name = f"{self.cargo_file.bin_name}.wasm"
@@ -61,8 +67,8 @@ class CargoFile:
 
         try:
             self._parse_file()
-        except Exception:
-            raise errors.BuildError("Can't read cargo file.")
+        except Exception as err:
+            raise errors.BuildError("Can't read or parse [Cargo.toml] file", err)
 
     def _parse_file(self):
         self.data = utils.read_toml_file(self.path)
